@@ -13,6 +13,7 @@ html_fragment <- function(number_sections = FALSE,
                           fig_height = 5,
                           fig_retina = if (!fig_caption) 2,
                           fig_caption = FALSE,
+                          dev = 'png',
                           smart = TRUE,
                           keep_md = FALSE,
                           pandoc_args = NULL,
@@ -21,7 +22,7 @@ html_fragment <- function(number_sections = FALSE,
   html_document(
     number_sections = number_sections, fig_width = fig_width,
     fig_height = fig_height, fig_retina = fig_retina, fig_caption = fig_caption,
-    smart = smart, keep_md = keep_md, pandoc_args = pandoc_args,
+    dev = dev, smart = smart, keep_md = keep_md, pandoc_args = pandoc_args,
     mathjax = NULL, highlight = NULL, theme = NULL, ...,
     template = rmarkdown_system_file("rmd/fragment/default.html")
   )
