@@ -6,6 +6,7 @@ ioslides_presentation <- function(logo = NULL,
                                   fig_height = 4.5,
                                   fig_retina = if (!fig_caption) 2,
                                   fig_caption = FALSE,
+                                  dev = 'png',
                                   smart = TRUE,
                                   self_contained = TRUE,
                                   widescreen = FALSE,
@@ -64,7 +65,7 @@ ioslides_presentation <- function(logo = NULL,
     args <- c()
 
     # create the files dir if it doesn't exist
-    if (!file.exists(files_dir))
+    if (!dir_exists(files_dir))
       dir.create(files_dir)
 
     # logo
@@ -181,7 +182,7 @@ ioslides_presentation <- function(logo = NULL,
 
   # return format
   output_format(
-    knitr = knitr_options_html(fig_width, fig_height, fig_retina, keep_md),
+    knitr = knitr_options_html(fig_width, fig_height, fig_retina, keep_md, dev),
     pandoc = pandoc_options(to = "html",
                             from = from_rmarkdown(fig_caption),
                             args = args),
