@@ -28,3 +28,10 @@ relative_to <- function(dir, file) {
   
   file
 }
+
+# A variant of relative_to that normalizes its inputs.
+normalized_relative_to <- function(dir, file) {
+  relative_to(
+    normalizePath(dir, winslash = "/", mustWork = FALSE),
+    normalizePath(file, winslash = "/", mustWork = FALSE))
+}
